#[non_exhaustive]pub enum TenantBindingError {
InvalidProvenance {
value: String,
},
InvalidWindow,
NotYetValid {
valid_from: OffsetDateTime,
now: OffsetDateTime,
},
Stale {
valid_until: OffsetDateTime,
now: OffsetDateTime,
},
AuthenticatedInFuture {
authenticated_at: OffsetDateTime,
now: OffsetDateTime,
},
}Expand description
Errors returned when constructing or validating a tenant binding.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidProvenance
Provenance was empty, contained controls, or exceeded its bound.
InvalidWindow
The validity window was empty, inverted, or inconsistent with evidence.
NotYetValid
The binding is not active yet.
Fields

valid_from: OffsetDateTimeStart of the binding validity window.

now: OffsetDateTimeClock time at which validation was attempted.
Stale
The binding is no longer active.
Fields

valid_until: OffsetDateTimeEnd of the binding validity window.

now: OffsetDateTimeClock time at which validation was attempted.
AuthenticatedInFuture
The application authentication evidence is from the future relative to the clock used at this authorization boundary.
Fields

authenticated_at: OffsetDateTimeTime recorded by the application verifier.

now: OffsetDateTimeClock time at which validation was attempted.