pub struct PendingDecision<O> { /* private fields */ }Expand description
An evaluated decision awaiting required persistence, not an authorization token.
The event is immutable. Retry its write using the same value, including its observation time and occurrence identity. A new evaluation is a new event.
Implementations
Sourceimpl<O> PendingDecision<O>
impl<O> PendingDecision<O>